aboutsummaryrefslogtreecommitdiffstats
path: root/yage/math/matrix.h
diff options
context:
space:
mode:
authorYann Herklotz <ymherklotz@gmail.com>2017-09-20 00:54:51 +0100
committerYann Herklotz <ymherklotz@gmail.com>2017-09-20 00:54:51 +0100
commit8a2b508eff6a9fc11c9e91316c8c3f8e9410848a (patch)
tree904eff225b63816a074e860008f139f4ab729934 /yage/math/matrix.h
parent8c5ea60da7f54b9ce574dfaca26bae67d775faa7 (diff)
downloadYAGE-8a2b508eff6a9fc11c9e91316c8c3f8e9410848a.tar.gz
YAGE-8a2b508eff6a9fc11c9e91316c8c3f8e9410848a.zip
Working on SpriteSheet
Diffstat (limited to 'yage/math/matrix.h')
-rw-r--r--yage/math/matrix.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/yage/math/matrix.h b/yage/math/matrix.h
index 7810d202..3df1509d 100644
--- a/yage/math/matrix.h
+++ b/yage/math/matrix.h
@@ -27,12 +27,12 @@ class Matrix;
/** @internal Namespace for internal details.
*
- * Detail Namespace
+ * Details Namespace
* ================
*
* This is the namespace used for implementation detail.
*/
-namespace detail
+namespace details
{
/** @internal Internal Row class used by the Matrix class to return the
@@ -68,7 +68,7 @@ public:
}
};
-} // namespace detail
+} // namespace details
/** Base Matrix class used by other similar classes.
*/
@@ -76,7 +76,7 @@ template <int Rows = 4, int Cols = 4, class Type = double>
class Matrix
{
// friended with the row class so that it can access protected member data.
- friend class detail::Row<Rows, Cols, Type>;
+ friend class details::Row<Rows, Cols, Type>;
protected:
/// Vector containing the data of the matrix.
@@ -158,14 +158,14 @@ public:
return ss.str();
}
- detail::Row<Rows, Cols, Type> operator[](int row)
+ details::Row<Rows, Cols, Type> operator[](int row)
{
- return detail::Row<Rows, Cols, Type>(this, row);
+ return details::Row<Rows, Cols, Type>(this, row);
}
- detail::Row<Rows, Cols, Type> operator[](int row) const
+ details::Row<Rows, Cols, Type> operator[](int row) const
{
- return detail::Row<Rows, Cols, Type>((Matrix<Rows, Cols, Type> *)this,
+ return details::Row<Rows, Cols, Type>((Matrix<Rows, Cols, Type> *)this,
row);
}
@@ -27,12 +27,12 @@ class Matrix;
* ================
*
- * This is the namespace used for implementation detail.
+ * This is the namespace used for implementation details.
*/